﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Windows.Controls;
using Infragistics;
using Infragistics.Controls.Grids;
using Infragistics.Controls.Grids.Primitives;

namespace XamGrid2
{
    public class CustomFilterSelectionControl : FilterSelectionControl
    {
        private ListBox lb;
        private Button ButtonOk;

        /* DOESN'T WORK */
        protected override void OnSelectAllCheckBoxChecked(CheckBox checkBoxSender)
        {
            base.OnSelectAllCheckBoxChecked(checkBoxSender);

            foreach (ListItem checkBox in this.lb.Items)
            {
                checkBox.IsChecked = (bool)checkBoxSender.IsChecked;
            }
        }

        protected override void AcceptChanges()
        {
            // This function get the clears the current row filters then adds 
            // new row filters based on the selected items in the listbox

            CellBase cell = this.Cell;
            string columnKey = cell.Column.Key;
            RowsManager rm = cell.Row.Manager as RowsManager;

            if (rm == null)
                return;

            RowsFilter rf = rm.RowFiltersCollectionResolved[columnKey];

            if (rf == null)
            {
                rf = new RowsFilter(typeof(Adresse), cell.Column);
                rm.RowFiltersCollection.Add(rf);
            }

            rf.Conditions.LogicalOperator = LogicalOperator.Or;

            rf.Conditions.Clear();
            
            ListBox lb = (ListBox)this.GetTemplateChild("itemsBox");

            foreach (ListItem li in lb.Items)
            {
                if (li.IsChecked)
                {
                    ComparisonCondition cc = new ComparisonCondition();
                    cc.Operator = ComparisonOperator.Contains;
                    cc.FilterValue = li.ContentString;
                    rf.Conditions.Add(cc);
                }
            }
        }

        protected override void SetupSelectionBox()
        {

            CellBase cell = this.Cell;

            if (cell == null)
                return;

            CheckBox selectAll = (CheckBox)this.GetTemplateChild("SelectAllCheckBox");

            if (selectAll == null)
                return;

            selectAll.Checked += selectAll_Checked;
            selectAll.Unchecked += selectAll_Unchecked;

            this.ButtonOk = (Button)this.GetTemplateChild("AcceptButton");

            this.lb = (ListBox)this.GetTemplateChild("itemsBox");
            
                if (lb == null)
                    return;

                if (lb.ItemsSource != null && lb.ItemsSource.GetType() == typeof(ObservableCollection<ListItem>))
                    return;

                RowsManager rm = this.Cell.Row.Manager as RowsManager;

                List<Adresse> col = (List<Adresse>)rm.ItemsSource;

                ObservableCollection<ListItem> _colors = new ObservableCollection<ListItem>();
                //List<ListItem> _colors = new List<ListItem>();
                this.UniqueValues.Clear();
                foreach (Adresse gd in col)
                {
                    _colors.Add(new ListItem() { IsChecked = false, ContentString = gd.Libelle.Numero + " " + gd.Libelle.Rue });

                    //this.UniqueValues.Add(new FilterValueProxy() { IsChecked = false, Value = gd.Libelle.Numero + " " + gd.Libelle.Rue });
                }

                this.ButtonOk.IsEnabled = true;

                if (lb != null)
                {
                    //(lb as ListBox).ItemsSource = _colors;
                    this.Dispatcher.BeginInvoke(delegate
                    {
                        (lb as ListBox).ItemsSource = _colors;
                    });
                }
        }

        void selectAll_Unchecked(object sender, System.Windows.RoutedEventArgs e)
        {
            foreach (ListItem checkBox in this.lb.Items)
            {
                checkBox.IsChecked = false;
            }
            this.ButtonOk.IsEnabled = false;
        }

        void selectAll_Checked(object sender, System.Windows.RoutedEventArgs e)
        {
            foreach (ListItem checkBox in this.lb.Items)
            {
                checkBox.IsChecked = true;
            }
            this.ButtonOk.IsEnabled = true;
        }
    }

    public class ListItem : INotifyPropertyChanged
    {
        private bool _isChecked;
        public bool IsChecked
        {
            get { return _isChecked; }
            set
            {
                if (_isChecked != value)
                {
                    _isChecked = value;
                    OnPropertyChanged("IsChecked");
                }
            }
        }

        private string _dispVal;
        public string ContentString
        {
            get { return _dispVal; }
            set
            {
                if (_dispVal != value)
                {
                    _dispVal = value;
                    OnPropertyChanged("ContentString");
                }
            }
        }
        public event PropertyChangedEventHandler PropertyChanged;
        protected virtual void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}
